@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 import os
 import sys
@@ -24,24 +26,28 @@ def np_from_pix(pix):
 
 
 if __name__ == '__main__':
-    
-    if not os.path.exists('tessdata'):
+
+    tessdata_prefix = os.environ.get('TESSDATA_PREFIX')
+    if not tessdata_prefix:
+      tessdata_prefix = 'tessdata'
+
+    if not os.path.exists(tessdata_prefix):
         # if you get this error, you need to download tesseract-ocr-3.02.eng.tar.gz 
         # and unpack it in this directory. 
         print >> sys.stderr, 'WARNING: tesseract OCR data directory was not found'
-    
+
     image_file = 'phototest.tif'
     if len(sys.argv) == 2:
         image_file = sys.argv[1]
-    
+
     api = tesseract.TessBaseAPI()
-    
-    if not api.Init('tessdata', 'eng', tesseract.OEM_DEFAULT):
+
+    if not api.Init(tessdata_prefix, 'eng', tesseract.OEM_DEFAULT):
         print >> sys.stderr, "Error initializing tesseract"
         exit(1)
 
     api.SetPageSegMode(tesseract.PSM_AUTO)
-    
+
     cvimg = cv2.imread(image_file)
     api.SetImage(cvimg)
     
